#![cfg_attr(docsrs, feature(doc_auto_cfg))]
#![allow(non_upper_case_globals)]
#![allow(non_camel_case_types)]
#![allow(non_snake_case)]

pub mod cta;
pub mod cvt;
pub mod displayid;
pub mod dmt;
pub mod edid;
pub mod gtf;
pub mod info;
